@@ -229,7 +229,7 @@ def main():
     if args.token is not None and (args.email is not None or args.key is not None):
         print('api token can not be used together with email and api key.', file=stderr)
         return 1
-    elif args.token is None or args.email is None or args.key is None:
+    elif args.token is None and (args.email is None or args.key is None):
         print('authentication information needed, please supply api token, or api email and api key.', file=stderr)
         return 1
 
